i-flow package
==============

Subpackages
-----------

.. toctree::

   iflow.integration
   iflow.splines

Module contents
---------------

.. automodule:: iflow
   :members:
   :undoc-members:
   :show-inheritance:
